powered by
Summarizing the fit of either hltm or hgrm.
hltm
hgrm
# S3 method for hIRT summary(object, by_item = FALSE, digits = 3, ...)# S3 method for summary_hIRT print(x, digits = 3, ...)
# S3 method for summary_hIRT print(x, digits = 3, ...)
An object of class hIRT.
hIRT
Logical. Should item parameters be stored item by item (if TRUE) or put together in a data frame (if FALSE)?
TRUE
FALSE
the number of significant digits to use when printing.
further arguments passed to print.
print
An object of class hIRT
An object of class summary_hIRT.
summary_hIRT
The matched call.
Model fit statistics: Log likelihood, AIC, and BIC.
Item parameter estimates, standard errors, z values, and p values.
Parameter estimates for the mean equation.
Parameter estimates for the variance equation.
# NOT RUN { y <- nes_econ2008[, -(1:3)] x <- model.matrix( ~ party * educ, nes_econ2008) z <- model.matrix( ~ party, nes_econ2008) nes_m1 <- hgrm(y, x, z) summary(nes_m1, by_item = TRUE) # }
Run the code above in your browser using DataLab